from bson.objectid import ObjectId
from stylelens_dataset.database import DataBase

class Images(DataBase):
  def __init__(self):
    super(Images, self).__init__()
    self.labels = self.db.labels

  def get_label_by_id(self, id):
    query = {"_id": ObjectId(id)}
    try:
      r = self.labels.find_one(query)
    except Exception as e:
      print(e)

    return r

  def get_label(self, index, clazz):
    query = {"index": index, "clazz": clazz}
    try:
      r = self.labels.find_one(query)
    except Exception as e:
      print(e)

    return r

  def add_label(self, label):
    label_id = None
    query = {"index": label["index"], "clazz": label["clazz"]}
    try:
      r = self.labels.update_one(query,
                                  {"$set": label},
                                  upsert=True)
    except Exception as e:
      print(e)

    if 'upserted' in r.raw_result:
      label_id = str(r.raw_result['upserted'])

    return label_id

  def get_labels(self, clazz,  offset=0, limit=50):
    query = {"clazz":clazz}

    try:
      r = self.labels.find(query).skip(offset).limit(limit)
    except Exception as e:
      print(e)

    return list(r)

  def update_label(self, label):
    try:
      r = self.labels.update_one({"_id": label['_id']},
                                  {"$set": label})
    except Exception as e:
      print(e)
      return None

    return r.raw_result

  def update_labels(self, labels):
    try:
      bulk = self.labels.initialize_unordered_bulk_op()
      for i in range(0, len(labels)):
        bulk.find({'_id': labels[i]['_id']}).update({'$set': labels[i]})
      r = bulk.execute()
      print(r)
    except Exception as e:
      print(e)



from bson.objectid import ObjectId
from stylelens_dataset.database import DataBase

class Colors(DataBase):
  def __init__(self):
    super(Colors, self).__init__()
    self.colors = self.db.colors
    self.classes = self.db.color_classes

  def add_color(self, object):
    id = None
    try:
      r = self.colors.update_one({"file": object['file']},
                                  {"$set": object},
                                  upsert=True)
    except Exception as e:
      print(e)

    if 'upserted' in r.raw_result:
      id = str(r.raw_result['upserted'])

    return id

  def get_classes(self, offset=0, limit=100):
    query = {}

    try:
      r = self.classes.find(query).skip(offset).limit(limit)
    except Exception as e:
      print(e)

    return list(r)

  def get_colors_by_name(self, name,  offset=0, limit=50):
    query = {}
    query['name'] = name

    try:
      r = self.colors.find(query).skip(offset).limit(limit)
    except Exception as e:
      print(e)
    return list(r)




from stylelens_dataset.database import DataBase

class Categories(DataBase):
  def __init__(self):
    super(Categories, self).__init__()
    self.categories = self.db.categories
    self.classes = self.db.category_classes

  def get_classes(self, offset=0, limit=100):
    query = {}

    try:
      r = self.classes.find(query).skip(offset).limit(limit)
    except Exception as e:
      print(e)

    return list(r)

  def add_category(self, category):
    id = None
    query = {"name": category["name"],
             "class_code": category["class_code"]}
    try:
      r = self.categories.update_one(query, {"$set": category},
                                upsert=True)
    except Exception as e:
      print(e)

    if 'upserted' in r.raw_result:
      id = str(r.raw_result['upserted'])

    return id

  def get_categories(self, offset=0, limit=100):
    try:
      r = self.categories.find().skip(offset).limit(limit)
    except Exception as e:
      print(e)

    return list(r)



from bson.objectid import ObjectId
from stylelens_dataset.database import DataBase

class Images(DataBase):
  def __init__(self):
    super(Images, self).__init__()
    self.images = self.db.images

  def get_image(self, id):
    try:
      r = self.images.find_one({"_id": ObjectId(id)})
    except Exception as e:
      print(e)

    return r

  def add_image(self, image):
    image_id = None
    try:
      r = self.images.update_one({"file": image['file']},
                                  {"$set": image},
                                  upsert=True)
    except Exception as e:
      print(e)

    if 'upserted' in r.raw_result:
      image_id = str(r.raw_result['upserted'])

    return image_id

  def get_images_by_source(self, source,  offset=0, limit=50):
    query = {"source":source}

    try:
      r = self.images.find(query).skip(offset).limit(limit)
    except Exception as e:
      print(e)

    return list(r)

  def get_images_by_category_class(self, clazz,  offset=0, limit=50):
    query = {"category_class":clazz}

    try:
      r = self.images.find(query).skip(offset).limit(limit)
    except Exception as e:
      print(e)

    return list(r)

  def update_image(self, image):
    try:
      r = self.images.update_one({"_id": image['_id']},
                                  {"$set": image})
    except Exception as e:
      print(e)
      return None

    return r.raw_result

  def update_images(self, images):
    try:
      bulk = self.images.initialize_unordered_bulk_op()
      for i in range(0, len(images)):
        bulk.find({'_id': images[i]['_id']}).update({'$set': images[i]})
      r = bulk.execute()
      print(r)
    except Exception as e:
      print(e)



from bson.objectid import ObjectId
from stylelens_dataset.database import DataBase

class Objects(DataBase):
  def __init__(self):
    super(Objects, self).__init__()
    self.objects = self.db.objects

  def get_object(self, object_id):
    try:
      r = self.objects.find_one({"_id": ObjectId(object_id)})
    except Exception as e:
      print(e)

    return r

  def add_object(self, object):
    object_id = None
    try:
      r = self.objects.update_one({"file": object['file']},
                                  {"$set": object},
                                  upsert=True)
    except Exception as e:
      print(e)

    if 'upserted' in r.raw_result:
      object_id = str(r.raw_result['upserted'])

    return object_id

  def get_objects_by_category(self, category,  offset=0, limit=50):
    query = {"category_class":category}

    try:
      r = self.objects.find(query).skip(offset).limit(limit)
    except Exception as e:
      print(e)

    return list(r)

  def get_objects_by_category_name(self, category_name,  offset=0, limit=50):
    query = {"category_name":category_name}

    try:
      r = self.objects.find(query).skip(offset).limit(limit)
    except Exception as e:
      print(e)

    return list(r)

  def get_objects_by_color(self, color,  offset=0, limit=50):
    query = {"color_class":color}

    try:
      r = self.objects.find(query).skip(offset).limit(limit)
    except Exception as e:
      print(e)

    return list(r)

  def get_objects_by_age(self, age,  offset=0, limit=50):
    query = {"age_class":age}

    try:
      r = self.objects.find(query).skip(offset).limit(limit)
    except Exception as e:
      print(e)

    return list(r)

  def get_objects_by_sex(self, sex,  offset=0, limit=50):
    query = {"sex_class":sex}

    try:
      r = self.objects.find(query).skip(offset).limit(limit)
    except Exception as e:
      print(e)

    return list(r)

  def get_objects_by_texture(self, texture,  offset=0, limit=50):
    query = {"texture_class":texture}

    try:
      r = self.objects.find(query).skip(offset).limit(limit)
    except Exception as e:
      print(e)

    return list(r)

  def get_objects_by_fabric(self, fabric,  offset=0, limit=50):
    query = {}
    query['fabric_class'] = {'$in': [fabric]}
    # db.getCollection('images').find({'fabric_class': {'$in': ['feather']}, '$where': 'this.fabric_class.length>1'})

    try:
      r = self.objects.find(query).where('this.fabric_class.length>1').skip(offset).limit(limit)
      # r = self.objects.find(query)
    except Exception as e:
      print(e)
    return list(r)

  def get_objects_by_shape(self, shape,  offset=0, limit=50):
    query = {"shape_class":shape}

    try:
      r = self.objects.find(query).skip(offset).limit(limit)
    except Exception as e:
      print(e)

    return list(r)

  def get_objects_by_style(self, style,  offset=0, limit=50):
    query = {"style_class":style}

    try:
      r = self.objects.find(query).skip(offset).limit(limit)
    except Exception as e:
      print(e)

    return list(r)

  def get_objects_by_look(self, look,  offset=0, limit=50):
    query = {"look_class":look}

    try:
      r = self.objects.find(query).skip(offset).limit(limit)
    except Exception as e:
      print(e)

    return list(r)

  def update_object(self, object):
    try:
      r = self.objects.update_one({"_id": object['_id']},
                                  {"$set": object})
    except Exception as e:
      print(e)
      return None

    return r.raw_result

  def update_objects(self, objects):
    try:
      bulk = self.objects.initialize_unordered_bulk_op()
      for i in range(0, len(objects)):
        bulk.find({'name': objects[i]['name']}).update({'$set': objects[i]})
      r = bulk.execute()
      print(r)
    except Exception as e:
      print(e)



from bson.objectid import ObjectId
from stylelens_dataset.database import DataBase

class Texts(DataBase):
  def __init__(self):
    super(Texts, self).__init__()
    self.texts = self.db.texts
    self.classes = self.db.text_classes

  def add_text(self, text):
    id = None
    query = {"text_code": text["text_code"], "text": text["text"]}
    try:
      r = self.texts.update_one(query, {"$set": text},
                                upsert=True)
    except Exception as e:
      print(e)

    if 'upserted' in r.raw_result:
      id = str(r.raw_result['upserted'])

    return id

  def get_texts(self, text_code,
                offset=0, limit=100):
    query = {"text_code": text_code}

    try:
      r = self.texts.find(query).skip(offset).limit(limit)
    except Exception as e:
      print(e)

    return list(r)

  def get_classes(self, offset=0, limit=100):
    query = {}

    try:
      r = self.classes.find(query).skip(offset).limit(limit)
    except Exception as e:
      print(e)

    return list(r)
